@@ -113,13 +113,14 @@ int ProxyHandler::Communication( SocketHandler *ProxyServerT, GenericScanner *Vi
         return -30;
     }
 
+
     ScannerOff = Whitelist.URLFound ( ToBrowser.GetHost(), ToBrowser.GetRequest() );
 
     if ( Blacklist.URLFound ( ToBrowser.GetHost(), ToBrowser.GetRequest() ) == true ) {
       LogFile::ErrorMessage("URL is blacklisted: %s\n", ToBrowser.GetCompleteRequest() );
       return -45;
     }
- 
+
     // #if defined (PARENTPROXY) && defined (PARENTPORT)
     string parentproxy=Params::GetConfigString("PARENTPROXY");
     int parentport=Params::GetConfigInt("PARENTPORT");
@@ -198,16 +199,17 @@ int ProxyHandler::Communication( SocketHandler *ProxyServerT, GenericScanner *Vi
         //IE Bug
         if ( ToBrowser.CheckForData() == true )
         {
-            if ( ToBrowser.Recv( &TempString, false) == false)
+            if ( ToBrowser.Recv( &TempString, false) < 0)
             {
               BrowserDropped = true;
               LogFile::ErrorMessage("Could not check for IE POST Bug %s Port %d\n", ToBrowser.GetHost(), ToBrowser.GetPort());
               return -76;
-            }
-
-            if ( TempString == "\r\n" )
+            } else if ( TempString == "\r\n" )
             {
                 ToBrowser.RecvLength( &TempString, 2);
+            } else if (TempString == "" )
+            {
+              //Browser shut down send. This could be ok??
             }
             else
             {
